django-permissions-auditor
==========================

[![](https://img.shields.io/pypi/v/nine.svg)](https://pypi.org/project/django-permissions-auditor/)
[![](https://readthedocs.org/projects/django-permissions-auditor/badge/?version=latest&style=flat)](https://django-permissions-auditor.readthedocs.io/en/latest/)


Automatically parse Django views in your project and pull out the permissions required to view them. Easily extensible to work with custom permission schemes.
